<?php
/**
 * Plugin Name:			Ocean Posts Slider
 * Plugin URI:			https://oceanwp.org/extension/ocean-posts-slider/
 * Description:			Display your latest posts in a beautiful slider with different options.
 * Version:				1.0.3.1
 * Author:				OceanWP
 * Author URI:			https://oceanwp.org/
 * Requires at least:	4.0.0
 * Tested up to:		4.7.2
 *
 * Text Domain: ocean-posts-slider
 * Domain Path: /languages/
 *
 * @package Ocean_Posts_Slider
 * @category Core
 * @author OceanWP
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Returns the main instance of Ocean_Posts_Slider to prevent the need to use globals.
 *
 * @since  1.0.0
 * @return object Ocean_Posts_Slider
 */
function Ocean_Posts_Slider() {
	return Ocean_Posts_Slider::instance();
} // End Ocean_Posts_Slider()

Ocean_Posts_Slider();

/**
 * Main Ocean_Posts_Slider Class
 *
 * @class Ocean_Posts_Slider
 * @version	1.0.0
 * @since 1.0.0
 * @package	Ocean_Posts_Slider
 */
final class Ocean_Posts_Slider {
	/**
	 * Ocean_Posts_Slider The single instance of Ocean_Posts_Slider.
	 * @var 	object
	 * @access  private
	 * @since 	1.0.0
	 */
	private static $_instance = null;

	/**
	 * The token.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $token;

	/**
	 * The version number.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $version;

	// Admin - Start
	/**
	 * The admin object.
	 * @var     object
	 * @access  public
	 * @since   1.0.0
	 */
	public $admin;

	/**
	 * Constructor function.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function __construct( $widget_areas = array() ) {
		$this->token 			= 'ocean-posts-slider';
		$this->plugin_url 		= plugin_dir_url( __FILE__ );
		$this->plugin_path 		= plugin_dir_path( __FILE__ );
		$this->version 			= '1.0.3.1';

		register_activation_hook( __FILE__, array( $this, 'install' ) );

		add_action( 'init', array( $this, 'ops_load_plugin_textdomain' ) );

		add_action( 'init', array( $this, 'ops_setup' ) );

		add_action( 'init', array( $this, 'register_post_type' ), 0 );
	}

	/**
	 * Main Ocean_Posts_Slider Instance
	 *
	 * Ensures only one instance of Ocean_Posts_Slider is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @static
	 * @see Ocean_Posts_Slider()
	 * @return Main Ocean_Posts_Slider instance
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) )
			self::$_instance = new self();
		return self::$_instance;
	} // End instance()

	/**
	 * Load the localisation file.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function ops_load_plugin_textdomain() {
		load_plugin_textdomain( 'ocean-posts-slider', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	}

	/**
	 * Cloning is forbidden.
	 *
	 * @since 1.0.0
	 */
	public function __clone() {
		_doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?' ), '1.0.0' );
	}

	/**
	 * Unserializing instances of this class is forbidden.
	 *
	 * @since 1.0.0
	 */
	public function __wakeup() {
		_doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?' ), '1.0.0' );
	}

	/**
	 * Installation.
	 * Runs on activation. Logs the version number and assigns a notice message to a WordPress option.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function install() {
		$this->_log_version_number();
	}

	/**
	 * Log the plugin version number.
	 * @access  private
	 * @since   1.0.0
	 * @return  void
	 */
	private function _log_version_number() {
		// Log the version number.
		update_option( $this->token . '-version', $this->version );
	}

	/**
	 * Setup all the things.
	 * Only executes if OceanWP or a child theme using OceanWP as a parent is active and the extension specific filter returns true.
	 * @return void
	 */
	public function ops_setup() {
		$theme = wp_get_theme();

		if ( 'OceanWP' == $theme->name || 'oceanwp' == $theme->template ) {
			require_once( $this->plugin_path .'/includes/image-resizer.php' );
			require_once( $this->plugin_path .'/includes/posts-slider.php' );
			add_action( 'wp_enqueue_scripts', array( $this, 'ops_scripts' ), 999 );
			add_action( 'admin_enqueue_scripts', array( $this, 'metabox_scripts' ) );
			add_action( 'oceanwp_butterbean_register', array( $this, 'metabox' ), 10, 2 );
			add_action( 'add_meta_boxes_ocean_posts_slider', array( $this, 'add_meta_box' ) );
		} else {
			add_action( 'admin_notices', array( $this, 'ops_install_ocean_notice' ) );
		}
	}

	/**
	 * OceanWP install
	 * If the user activates the plugin while having a different parent theme active, prompt them to install OceanWP.
	 * @since   1.0.0
	 * @return  void
	 */
	public function ops_install_ocean_notice() {
		echo '<div class="notice is-dismissible updated">
				<p>' . esc_html__( 'Ocean Posts Slider requires that you use OceanWP as your parent theme.', 'ocean-posts-slider' ) . ' <a href="https://oceanwp.org/">' . esc_html__( 'Install OceanWP Now', 'ocean-posts-slider' ) . '</a></p>
			</div>';
	}

	/**
	 * Enqueue scripts.
	 * @since   1.0.0
	 */
	public function ops_scripts() {

		// Load main stylesheet
		wp_enqueue_style( 'ops-styles', plugins_url( '/assets/css/style.min.css', __FILE__ ) );
		
		// Load custom js methods.
		wp_enqueue_script( 'ops-js-scripts', plugins_url( '/assets/js/main.min.js', __FILE__ ), array( 'jquery', 'oceanwp-main' ), null, true );

	}

	/**
	 * Register custom post type
	 */
	public static function register_post_type() {
		register_post_type( 'ocean_posts_slider', apply_filters( 'ocean_posts_slider_args', array(
			'labels' => array(
				'name' 					=> esc_html__( 'Posts Slider', 'ocean-posts-slider' ),
				'singular_name' 		=> esc_html__( 'Posts Slider Item', 'ocean-posts-slider' ),
				'add_new' 				=> esc_html__( 'Add New', 'ocean-posts-slider' ),
				'add_new_item' 			=> esc_html__( 'Add New Item', 'ocean-posts-slider' ),
				'edit_item' 			=> esc_html__( 'Edit Item', 'ocean-posts-slider' ),
				'new_item' 				=> esc_html__( 'Add New Item', 'ocean-posts-slider' ),
				'view_item' 			=> esc_html__( 'View Item', 'ocean-posts-slider' ),
				'search_items' 			=> esc_html__( 'Search Items', 'ocean-posts-slider' ),
				'not_found' 			=> esc_html__( 'No Items Found', 'ocean-posts-slider' ),
				'not_found_in_trash' 	=> esc_html__( 'No Items Found In Trash', 'ocean-posts-slider' )
			),
			'public' 					=> false,
			'has_archive' 				=> false,
			'hierarchical'          	=> false,
			'show_ui'               	=> true,
			'show_in_menu'          	=> true,
			'show_in_admin_bar'     	=> false,
			'show_in_nav_menus'     	=> false,
			'can_export'            	=> true,
			'has_archive'           	=> false,		
			'exclude_from_search'   	=> true,
			'publicly_queryable'    	=> false,
			'capability_type' 			=> 'page',
			'menu_icon' 				=> 'dashicons-format-gallery',
			'menu_position' 			=> 20,
			'supports' 					=> array( 'title' ),
		) ) );
	}

	/**
	 * Load metabox scripts
	 */
	public function metabox_scripts() {

		// Enqueue the main script.
		wp_enqueue_script( 'oceanwp-metabox-script', plugins_url( '/assets/js/metabox.min.js', __FILE__ ), array( 'jquery' ), $this->version, true );

	}

	/**
	 * Registration callback
 	 */
	public function metabox( $butterbean, $post_type ) {

		if ( 'ocean_posts_slider' !== $post_type ) {
			return;
		}

		// Register managers, sections, controls, and settings here.
		$butterbean->register_manager(
	        'oceanwp_ps_settings',
	        array(
	            'label'     => esc_html__( 'Posts Slider Settings', 'ocean-posts-slider' ),
	            'post_type' => 'ocean_posts_slider',
	            'context'   => 'normal',
	            'priority'  => 'high'
	        )
	    );
		
		$manager = $butterbean->get_manager( 'oceanwp_ps_settings' );
		
		$manager->register_section(
	        'oceanwp_ps_general',
	        array(
	            'label' => esc_html__( 'General', 'ocean-posts-slider' ),
	            'icon'  => 'dashicons-admin-tools'
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_style', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_general',
	            'type'    		=> 'select',
	            'label'   		=> esc_html__( 'Style', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Select the slider style.', 'ocean-posts-slider' ),
				'choices' 		=> array(
					'one' 		=> esc_html__( 'One Image', 'ocean-posts-slider' ),
					'two' 		=> esc_html__( 'Three Images', 'ocean-posts-slider' ),
				),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_style', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_number', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_general',
	            'type'    		=> 'number',
	            'label'   		=> esc_html__( 'Number', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Enter the number of posts to display.', 'ocean-posts-slider' ),
				'attr'    		=> array(
					'min' 	=> '0',
					'step' 	=> '1',
				),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_number', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_number_per_slide', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_general',
	            'type'    		=> 'number',
	            'label'   		=> esc_html__( 'Number Per Slide', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Enter the number of posts to display per slide.', 'ocean-posts-slider' ),
				'attr'    		=> array(
					'min' 	=> '0',
					'step' 	=> '1',
				),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_number_per_slide', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_size', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_general',
	            'type'    		=> 'select',
	            'label'   		=> esc_html__( 'Size', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Select the size of your images.', 'ocean-posts-slider' ),
				'choices' 		=> array(
					'thumbnail' 	=> esc_html__( 'Thumbnail (150 x 150 hard cropped)', 'ocean-posts-slider' ),
					'medium' 		=> esc_html__( 'Medium (300 x 300 max height 300px)', 'ocean-posts-slider' ),
					'medium_large' 	=> esc_html__( 'Medium Large (768 x 0 infinite height)', 'ocean-posts-slider' ),
					'large' 		=> esc_html__( 'Large (1024 x 1024 max height 1024px)', 'ocean-posts-slider' ),
					'full' 			=> esc_html__( 'Full (original size uploaded)', 'ocean-posts-slider' ),
					'custom' 		=> esc_html__( 'Custom (enter your custom image size)', 'ocean-posts-slider' ),
				),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_size', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_img_width', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_general',
	            'type'    		=> 'number',
	            'label'   		=> esc_html__( 'Image Width', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Enter your custom image width.', 'ocean-posts-slider' ),
				'attr'    		=> array(
					'min' 	=> '0',
					'step' 	=> '1',
				),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_img_width', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_img_height', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_general',
	            'type'    		=> 'number',
	            'label'   		=> esc_html__( 'Image Height', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Enter your custom image height.', 'ocean-posts-slider' ),
				'attr'    		=> array(
					'min' 	=> '0',
					'step' 	=> '1',
				),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_img_height', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_more_text', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_general',
	            'type'    		=> 'text',
	            'label'   		=> esc_html__( 'Read More Text', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Enter your custom text for the read more button.', 'ocean-posts-slider' ),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_more_text', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
				'default' 			=> esc_html__( 'Read More', 'ocean-posts-slider' ),
	        )
	    );
		
		$manager->register_section(
	        'oceanwp_ps_slide',
	        array(
	            'label' => esc_html__( 'Slide', 'ocean-posts-slider' ),
	            'icon'  => 'dashicons-images-alt2'
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_margin', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_slide',
	            'type'    		=> 'text',
	            'label'   		=> esc_html__( 'Margin', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Add a space between the slider and your content. eg 0 0 20px 0 (top right bottom left).', 'ocean-posts-slider' ),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_margin', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_speed', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_slide',
	            'type'    		=> 'number',
	            'label'   		=> esc_html__( 'Speed', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Enter the transition speed of the slides.', 'ocean-posts-slider' ),
				'attr'    		=> array(
					'min' 	=> '0',
					'step' 	=> '1',
				),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_speed', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
				'default' 			=> '7000',
	        )
	    );
		
		$manager->register_section(
	        'oceanwp_ps_posts',
	        array(
	            'label' => esc_html__( 'Posts', 'ocean-posts-slider' ),
	            'icon'  => 'dashicons-admin-post'
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_exclude_cat', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_posts',
	            'type'    		=> 'text',
	            'label'   		=> esc_html__( 'Exclude Cat', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Enter the slug of your category to exclude, separate cat by commas.', 'ocean-posts-slider' ),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_exclude_cat', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_order', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_posts',
	            'type'    		=> 'select',
	            'label'   		=> esc_html__( 'Order', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Designates the ascending or descending order.', 'ocean-posts-slider' ),
				'choices' 		=> array(
					'ASC' 		=> esc_html__( 'Ascending Order', 'ocean-posts-slider' ),
					'DESC' 		=> esc_html__( 'Descending Order', 'ocean-posts-slider' ),
				),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_order', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
				'default' 			=> 'DESC',
	        )
	    );

	    $manager->register_control(
	        'oceanwp_ps_orderby', // Same as setting name.
	        array(
	            'section' 		=> 'oceanwp_ps_posts',
	            'type'    		=> 'select',
	            'label'   		=> esc_html__( 'Order By', 'ocean-posts-slider' ),
	            'description'   => esc_html__( 'Sort retrieved posts by parameter.', 'ocean-posts-slider' ),
				'choices' 		=> array(
					'none' 				=> esc_html__( 'No Order', 'ocean-posts-slider' ),
					'ID' 				=> esc_html__( 'ID', 'ocean-posts-slider' ),
					'author' 			=> esc_html__( 'Author', 'ocean-posts-slider' ),
					'title' 			=> esc_html__( 'Title', 'ocean-posts-slider' ),
					'name' 				=> esc_html__( 'Slug', 'ocean-posts-slider' ),
					'type' 				=> esc_html__( 'Post Type', 'ocean-posts-slider' ),
					'date' 				=> esc_html__( 'Date', 'ocean-posts-slider' ),
					'modified' 			=> esc_html__( 'Modified', 'ocean-posts-slider' ),
					'parent' 			=> esc_html__( 'Parent', 'ocean-posts-slider' ),
					'rand' 				=> esc_html__( 'Random', 'ocean-posts-slider' ),
					'comment_count' 	=> esc_html__( 'Comment Count', 'ocean-posts-slider' )
				),
	        )
	    );
			
		$manager->register_setting(
	        'oceanwp_ps_orderby', // Same as control name.
	        array(
	            'sanitize_callback' => 'sanitize_text_field',
				'default' 			=> 'date',
	        )
	    );

	}

	/**
	 * Add shorcode metabox
	 */
	public function add_meta_box( $post ) {

		add_meta_box(
			'oceanwp-ps-shortcode-metabox',
			esc_html__( 'Shortcode', 'ocean-posts-slider' ),
			array( $this, 'display_meta_box' ),
			'ocean_posts_slider',
			'side',
			'low'
		);

	}

	/**
	 * Add shorcode metabox
	 */
	public function display_meta_box( $post ) { ?>

		<input type="text" class="widefat" value='[ocean_posts_slider id="<?php echo $post->ID;?>"]' readonly />

	<?php
	}

} // End Class
